# Global options.


class style:
    """
    Styling global options for misura.
    """

    quantityHighlighting = True


class defined:
    """
    User defined units.
    """

    BASE_TABLE = {}
    DERIVED_TABLE = {}
    DERIVED_UNPACKING_TABLE = {}
